@@ -1,13 +1,15 @@
 """Find new version on github or pypi."""
 import json
 import re
+from distutils.version import LooseVersion
+from typing import Optional
 
 from PySide2 import QtCore, QtWidgets
 
 from normcap import __version__
+from normcap.data import URLS
 from normcap.gui.downloader import Downloader
 from normcap.logger import logger
-from normcap.models import URLS
 from normcap.utils import get_icon, set_cursor
 
 
@@ -27,17 +29,21 @@ class UpdateChecker(QtCore.QObject):
         self.com = Communicate()
         self.downloader = Downloader()
         self.downloader.com.on_download_finished.connect(self._check_if_new)
+        self.message_box = self._create_message_box()
 
     def _check_if_new(self, text: str):
         """Check if retrieved version is new."""
-        newest_version = self._parse_response(text)
-        logger.debug(f"Version found: {newest_version} (installed={__version__})")
-        if newest_version not in ["", __version__]:
-            self.com.on_version_retrieved.emit(newest_version)
+        newest_version = self._parse_response_to_version(text)
+        if newest_version:
+            logger.debug(
+                "Newest version: %s (installed: %s)", newest_version, __version__
+            )
+            if LooseVersion(newest_version) > LooseVersion(__version__):
+                self.com.on_version_retrieved.emit(newest_version)
 
-    def _parse_response(self, text: str):
+    def _parse_response_to_version(self, text: str) -> Optional[str]:
         """Parse the tag version from the response and emit version retrieved signal."""
-        newest_version = ""
+        newest_version = None
 
         try:
             if self.packaged:
@@ -50,17 +56,31 @@ class UpdateChecker(QtCore.QObject):
         except Exception:  # pylint: disable=broad-except
             logger.exception("Couldn't parse update check response")
 
-        if newest_version == "":
-            logger.error("Couldn't parse newest version")
+        if not newest_version:
+            logger.error("Couldn't parse newest version! Update check won't work!")
 
         return newest_version
 
     def check(self):
         """Start the update check."""
         url = URLS.releases if self.packaged else f"{URLS.pypi}/json"
-        logger.debug(f"Search for new version on {url}")
+        logger.debug("Search for new version on %s", url)
         self.downloader.get(url)
 
+    @staticmethod
+    def _create_message_box():
+        message_box = QtWidgets.QMessageBox()
+
+        # Necessary on wayland for main window to regain focus:
+        message_box.setWindowFlags(QtCore.Qt.Popup)
+
+        message_box.setIconPixmap(get_icon("normcap.png").pixmap(48, 48))
+        message_box.setStandardButtons(
+            QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel
+        )
+        message_box.setDefaultButton(QtWidgets.QMessageBox.Ok)
+        return message_box
+
     def show_update_message(self, new_version):
         """Show dialog informing about available update."""
 
@@ -71,29 +91,21 @@ class UpdateChecker(QtCore.QObject):
                 "GitHub.\n\n"
                 "Do you want to visit the release website now?"
             )
+            update_url = URLS.releases
         else:
             info_text = (
                 "You should be able to upgrade from command line with "
                 "'pip install normcap --upgrade'.\n\n"
-                "Do you want to visit the release website now?"
+                "Do you want to view the changelog on github?"
             )
+            update_url = URLS.changelog
 
-        message_box = QtWidgets.QMessageBox()
-
-        # Necessary on wayland for main window to regain focus:
-        message_box.setWindowFlags(QtCore.Qt.Popup)
-
-        message_box.setIconPixmap(get_icon("normcap.png").pixmap(48, 48))
-        message_box.setText(text)
-        message_box.setInformativeText(info_text)
-        message_box.setStandardButtons(
-            QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel
-        )
-        message_box.setDefaultButton(QtWidgets.QMessageBox.Ok)
+        self.message_box.setText(text)
+        self.message_box.setInformativeText(info_text)
 
         set_cursor(QtCore.Qt.ArrowCursor)
-        choice = message_box.exec_()
+        choice = self.message_box.exec_()
         set_cursor(QtCore.Qt.CrossCursor)
 
         if choice == 1024:
-            self.com.on_click_get_new_version.emit(URLS.releases)
+            self.com.on_click_get_new_version.emit(update_url)
