@@ -1,39 +1,65 @@
-"""Detect OCR tool & language and perform OCR on selected part of image."""
+"""Detect OCR tool & language and perform OCR on selected part of image.
+
+Tesseract options (for reference):
+
+    tesserocr.PSM:
+        OSD_ONLY: Orientation and script detection (OSD) only.
+        AUTO_OSD: Automatic page segmentation with orientation & script detection.
+        AUTO_ONLY: Automatic page segmentation, but no OSD, or OCR.
+        AUTO: Fully automatic page segmentation, but no OSD. (`tesserocr` default)
+        SINGLE_COLUMN: Assume a single column of text of variable sizes.
+        SINGLE_BLOCK_VERT_TEXT: Assume a  uniform block of vertically aligned text.
+        SINGLE_BLOCK: Assume a single uniform block of text.
+        SINGLE_LINE: Treat the image as a single text line.
+        SINGLE_WORD: Treat the image as a single word.
+        CIRCLE_WORD: Treat the image as a single word in a circle.
+        SINGLE_CHAR: Treat the image as a single character.
+        SPARSE_TEXT: Find as much text as possible in no particular order.
+        SPARSE_TEXT_OSD: Sparse text with orientation and script det.
+        RAW_LINE: Treat the image as a single text line, bypassing Tesseract hacks.
+        COUNT: Number of enum entries.
+
+    tesserocr.OEM:
+        TESSERACT_ONLY: Run Tesseract only - fastest
+        LSTM_ONLY: Run just the LSTM line recognizer. (>=v4.00)
+        TESSERACT_LSTM_COMBINED: Run the LSTM recognizer, but allow fallback
+            to Tesseract when things get difficult. (>=v4.00)
+        CUBE_ONLY: Specify this mode when calling Init*(), to indicate that
+            any of the above modes should be automatically inferred from the
+            variables in the language-specific config, command-line configs, or
+            if not specified in any of the above should be set to the default
+            `OEM.TESSERACT_ONLY`.
+        TESSERACT_CUBE_COMBINED: Run Cube only - better accuracy, but slower.
+        DEFAULT: Run both and combine results - best accuracy.
+"""
 
 import csv
 import statistics
-from typing import List, Set
+from typing import List
 
 from PySide2 import QtGui
 
+from normcap import system_info
 from normcap.logger import logger
-from normcap.models import Capture, SystemInfo
-from normcap.utils import tesserocr
+from normcap.models import Capture
+from normcap.system_info import tesserocr
 
 
 class PerformOcr:
     """Handles the text recognition task."""
 
-    languages: Set[str]
-    tessdata_path: str
+    tess_args: dict
 
-    def __call__(self, languages: List[str], capture: Capture, system_info: SystemInfo):
-        """Apply OCR on selected image section.
-        Arguments:
-            AbstractHandler {class} -- self
-            request {Capture} -- NormCap's session data
-        Returns:
-            Capture -- Enriched NormCap's session data
-        """
-        self.tessdata_path = system_info.tessdata_path
-        self.languages = self.sanatize_language(
-            languages, system_info.tesseract_languages
+    def __call__(self, languages: List[str], capture: Capture) -> Capture:
+        """Apply OCR on selected image section."""
+        languages = self.sanatize_language(languages, system_info.tesseract().languages)
+        self.tess_args = dict(
+            path=system_info.tesseract().path,
+            lang="+".join(languages),
+            oem=tesserocr.OEM.LSTM_ONLY,
+            psm=tesserocr.PSM.AUTO_OSD,
         )
-
-        # TODO: Tessdata Path empty?
-        logger.debug(f"Using tessdata in '{self.tessdata_path}'")
-        logger.info(f"Using language '{self.languages}'")
-
+        logger.debug("Init tesseract with args: %s", self.tess_args)
         capture = self.extract(capture)
         return capture
 
@@ -43,45 +69,7 @@ class PerformOcr:
         if not isinstance(capture.image, QtGui.QImage):
             raise TypeError("No image for OCR available!")
 
-        # OSD_ONLY: Orientation and script detection (OSD) only.
-        # AUTO_OSD: Automatic page segmentation with orientation & script detection.
-        # AUTO_ONLY: Automatic page segmentation, but no OSD, or OCR.
-        # AUTO: Fully automatic page segmentation, but no OSD. (`tesserocr` default)
-        # SINGLE_COLUMN: Assume a single column of text of variable sizes.
-        # SINGLE_BLOCK_VERT_TEXT: Assume a  uniform block of vertically aligned text.
-        # SINGLE_BLOCK: Assume a single uniform block of text.
-        # SINGLE_LINE: Treat the image as a single text line.
-        # SINGLE_WORD: Treat the image as a single word.
-        # CIRCLE_WORD: Treat the image as a single word in a circle.
-        # SINGLE_CHAR: Treat the image as a single character.
-        # SPARSE_TEXT: Find as much text as possible in no particular order.
-        # SPARSE_TEXT_OSD: Sparse text with orientation and script det.
-        # RAW_LINE: Treat the image as a single text line, bypassing Tesseract hacks.
-        # COUNT: Number of enum entries.
-        psm_opt = tesserocr.PSM.AUTO_OSD
-
-        # TESSERACT_ONLY: Run Tesseract only - fastest
-        # LSTM_ONLY: Run just the LSTM line recognizer. (>=v4.00)
-        # TESSERACT_LSTM_COMBINED: Run the LSTM recognizer, but allow fallback
-        #     to Tesseract when things get difficult. (>=v4.00)
-        # CUBE_ONLY: Specify this mode when calling Init*(), to indicate that
-        #     any of the above modes should be automatically inferred from the
-        #     variables in the language-specific config, command-line configs, or
-        #     if not specified in any of the above should be set to the default
-        #     `OEM.TESSERACT_ONLY`.
-        # TESSERACT_CUBE_COMBINED: Run Cube only - better accuracy, but slower.
-        # DEFAULT: Run both and combine results - best accuracy.
-        oem_opt = tesserocr.OEM.LSTM_ONLY
-
-        with tesserocr.PyTessBaseAPI(
-            path=self.tessdata_path,
-            lang="+".join(list(self.languages)),
-            oem=oem_opt,
-            psm=psm_opt,
-        ) as api:
-            # api.SetImage(capture.image)
-            # imagedata, int width, int height,
-            # int bytes_per_pixel, int bytes_per_line)
+        with tesserocr.PyTessBaseAPI(**self.tess_args) as api:
             img = capture.image
             api.SetImageBytes(
                 bytes(img.constBits()),
@@ -95,16 +83,17 @@ class PerformOcr:
 
         mean_conf = statistics.mean([w.get("conf", 0) for w in words] + [0])
         logger.info(
-            f"PSM Mode: {psm_opt}, OSM Mode: {oem_opt}, "
+            f"PSM Mode: {self.tess_args['psm']}, "
+            + f"OSM Mode: {self.tess_args['oem']}, "
             + f"Mean Conf: {mean_conf:.2f}"
         )
 
         capture.words = words
-        capture.psm_opt = psm_opt
+        capture.psm_opt = self.tess_args["psm"]
 
         return capture
 
-    def extract_best(self, img, lang) -> Capture:
+    def extract_best(self, img) -> Capture:
         """Recognize text in image and return structured dict."""
 
         # Workaround for a pyinstaller bug on Windows:
@@ -118,9 +107,7 @@ class PerformOcr:
 
         for psm_opt in psm_opts:
             # OCR
-            with tesserocr.PyTessBaseAPI(
-                lang=lang, oem=tesserocr.OEM.LSTM_ONLY, psm=psm_opt
-            ) as api:
+            with tesserocr.PyTessBaseAPI(**self.tess_args, psm=psm_opt) as api:
                 api.SetImage(img)
                 tsv_data = api.GetTSVText(0)
             words = self.tsv_to_list_of_dicts(tsv_data)
@@ -180,7 +167,7 @@ class PerformOcr:
     @staticmethod
     def sanatize_language(
         config_languages: List[str], tesseract_languages: List[str]
-    ) -> Set[str]:
+    ) -> List[str]:
         """Retrieve tesseract version number."""
         set_config_languages = set(config_languages)
         set_tesseract_languages = set(tesseract_languages)
@@ -188,19 +175,19 @@ class PerformOcr:
         available_langs = set_config_languages.intersection(set_tesseract_languages)
 
         if not unavailable_langs:
-            return set_config_languages
+            return list(set_config_languages)
 
         logger.warning(
             f"Languages {unavailable_langs} not found. "
             + f"Available on the system are: {set_tesseract_languages}"
         )
         if available_langs:
-            logger.warning(f"Fallback to languages {available_langs}")
-            return available_langs
+            logger.warning("Fallback to languages %s", available_langs)
+            return list(available_langs)
 
         fallback_language = set_tesseract_languages.pop()
-        logger.warning(f"Fallback to language {fallback_language}")
-        return set([fallback_language])
+        logger.warning("Fallback to language %s", fallback_language)
+        return list(set([fallback_language]))
 
 
 perform_ocr = PerformOcr()
